@@ -1,12 +1,12 @@
-use crate::event_codes::KeyOrButton;
+use crate::event_codes::Key;
 use crate::GenericEvent;
 
 /// Button event
 ///
 /// This event is wrapped with mappings for a specific device.
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
 pub struct ButtonEvent {
-	button: KeyOrButton,
+	button: Key,
 	is_synthetic: bool,
 	time: u32,
 	value: i16,
@@ -14,11 +14,11 @@ pub struct ButtonEvent {
 
 impl ButtonEvent {
 	/// Returns the event's mapped axis
-	pub const fn button(&self) -> KeyOrButton {
+	pub const fn button(&self) -> Key {
 		self.button
 	}
 
-	pub(crate) const fn new(button: KeyOrButton, is_synthetic: bool, time: u32, value: i16) -> Self {
+	pub(crate) const fn new(button: Key, is_synthetic: bool, time: u32, value: i16) -> Self {
 		ButtonEvent {
 			button,
 			is_synthetic,
