@@ -2,9 +2,8 @@ use crate::{AxisEvent, ButtonEvent, Device, Event, EventType, GenericEvent};
 
 /// Wrapped event
 ///
-/// Device events wrap axis and button events. This is intended for use with the builtin [`Device`](struct.Device.html)
-/// abstraction.
-#[derive(Clone, Copy, Debug)]
+/// Device events wrap axis and button events. This is intended for use with the builtin [`Device`](struct.Device.html) abstraction.
+#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
 pub enum DeviceEvent {
 	/// Axis event
 	Axis(AxisEvent),
