@@ -1,7 +1,7 @@
 use sys::{JS_EVENT_AXIS, JS_EVENT_BUTTON, JS_EVENT_INIT};
 
 /// Event types
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
 #[repr(u8)]
 pub enum EventType {
 	/// Real axis event
