@@ -1,5 +1,11 @@
+use std::fmt::Debug;
+use std::hash::Hash;
+
 /// Trait common to all events
-pub trait GenericEvent {
+pub trait GenericEvent
+where
+	Self: Clone + Copy + Debug + Eq + Hash + PartialEq,
+{
 	/// Returns `true` if the event is real
 	fn is_real(&self) -> bool;
 
